@@ -1,12 +1,12 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import unittest
 import doctest
 import datetime
 from decimal import Decimal
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
-    test_depends
+from trytond.tests.test_tryton import ModuleTestCase
+from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT
 from trytond.tests.test_tryton import doctest_setup, doctest_teardown
 from trytond.transaction import Transaction
 
@@ -22,11 +22,12 @@ DATES = [
     ]
 
 
-class StockSupplyTestCase(unittest.TestCase):
+class StockSupplyTestCase(ModuleTestCase):
     'Test StockSupply module'
+    module = 'stock_supply'
 
     def setUp(self):
-        trytond.tests.test_tryton.install_module('stock_supply')
+        super(StockSupplyTestCase, self).setUp()
         self.uom = POOL.get('product.uom')
         self.uom_category = POOL.get('product.uom.category')
         self.category = POOL.get('product.category')
@@ -38,14 +39,6 @@ class StockSupplyTestCase(unittest.TestCase):
         self.product_supplier = POOL.get('purchase.product_supplier')
         self.user = POOL.get('res.user')
 
-    def test0005views(self):
-        'Test views'
-        test_view('stock_supply')
-
-    def test0006depends(self):
-        'Test depends'
-        test_depends()
-
     def test0010compute_supply_date(self):
         'Test compute_supply_date'
         for purchase_date, delivery_time, supply_date in DATES:
@@ -124,7 +117,7 @@ def suite():
     suite = trytond.tests.test_tryton.suite()
     from trytond.modules.company.tests import test_company
     for test in test_company.suite():
-        if test not in suite:
+        if test not in suite and not isinstance(test, doctest.DocTestCase):
             suite.addTest(test)
     from trytond.modules.account.tests import test_account
     for test in test_account.suite():
